@@ -75,9 +75,8 @@ class DiegoOperator(PythonOperator):
     def __upload_df_to_s3_temp(self, df: pd.DataFrame, path, part_number, pandas_kwargs=None):
         if pandas_kwargs is None:
             pandas_kwargs = dict()
-        # df.to_parquet(path=f"{path}/{part_number}.parquet")
         wr.s3.to_parquet(
-            dataframe=df,
+            df=df,
             path=f"{path}/{part_number}.parquet"
 )
 
@@ -120,7 +119,7 @@ class DiegoOperator(PythonOperator):
     def execute(self, context):
         df = super().execute(context)
 
-        temp_file_path = f"s3://cortex-data-lakehouse-metastore-development/temp-files-diego/{self.task_id}/{self.cube_id}/{str(hash(datetime.utcnow().isoformat()))}"
+        temp_file_path = f"cortex-data-lakehouse-metastore-development/temp-files-diego/{self.task_id}/{self.cube_id}/{str(hash(datetime.utcnow().isoformat()))}"
 
         if isinstance(df, collections.Iterator):
             for part_number, df_part in enumerate(df):
@@ -128,9 +127,9 @@ class DiegoOperator(PythonOperator):
         else:
             self.__execute_df(df=df, part_number=1, path=temp_file_path)
 
-        self.send_file_path_to_diego(temp_file_path)
+        response = self.send_file_path_to_diego(temp_file_path)
 
-        if not self.ignore_empty_dataframe:
+        if not self.ignore_empty_dataframe and not response.json().get("replyId"):
             raise ValueError('There were no dataframes written to Diego. Please check if your dataframes are empty')
 
         context['task_instance'].xcom_push(key='platform_url', value=self.platform_url)
